from aiovantage.objects import LightSensor

from .base import BaseController


class LightSensorsController(BaseController[LightSensor]):
    """Light sensors controller."""

    vantage_types = ("LightSensor",)



from aiovantage.objects import LoadGroup

from .base import BaseController


class LoadGroupsController(BaseController[LoadGroup]):
    """Load groups controller."""

    vantage_types = ("LoadGroup",)



from aiovantage.objects import GMem

from .base import BaseController


class GMemController(BaseController[GMem]):
    """GMem (variables) controller."""

    vantage_types = ("GMem",)
    category_status = True



from aiovantage.objects import DryContact

from .base import BaseController


class DryContactsController(BaseController[DryContact]):
    """Dry contacts controller."""

    vantage_types = ("DryContact",)



from aiovantage.objects import AnemoSensor

from .base import BaseController


class AnemoSensorsController(BaseController[AnemoSensor]):
    """Anemo sensors (wind speed sensors) controller."""

    vantage_types = ("AnemoSensor",)
